TMAPI in Django
===============

This project aims to provide a full implementation of the `Topic Maps
API 2.0`_ using the Python web application framework `Django`_. It is
intended to be used by other Django applications, and does not provide
a web interface to the API.

.. _Django: http://www.djangoproject.com/
.. _Topic Maps API 2.0: http://www.tmapi.org/2.0/
